@@ -16,15 +16,25 @@ describe Nanoc::Checking::Checks::InternalLinks do
   let(:items)         { Nanoc::Core::ItemCollection.new(config, []) }
   let(:layouts)       { Nanoc::Core::LayoutCollection.new(config, []) }
 
+  around do |ex|
+    FileUtils.mkdir('site with spaces')
+    Dir.chdir('site with spaces') do
+      ex.run
+    end
+  end
+
   before do
     FileUtils.mkdir_p('output')
     File.write('Rules', 'passthrough "/**/*"')
   end
 
+  # FIXME: deduplicate
   def path_to_file_uri(path, dir)
     output_dir = dir.is_a?(String) ? dir : dir.config.output_dir
     output_dir += '/' unless output_dir.end_with?('/')
-    URI.join("file://#{output_dir}", path).to_s
+
+    uri = Addressable::URI.convert_path(output_dir) + Addressable::URI.convert_path(path)
+    uri.to_s
   end
 
   it 'detects non-broken links' do
