@@ -24,8 +24,8 @@ EOS
   end
 
   it 'finds the parent if the parent is root' do
-    site = Nanoc::Int::SiteLoader.new.new_from_cwd
-    site.compile
+    site = Nanoc::Core::SiteLoader.new.new_from_cwd
+    Nanoc::Core::Compiler.compile(site)
 
     expect(File.read('output/donkey/index.html')).to eql('Donkey! [/]')
   end
